Properties Methods Events Direct Link

# Class Ext.ux.tree.TreeGrid

Package: | Ext.ux.tree
Defined In: | TreeGrid.js
Class: | TreeGrid
Extends: | Object

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| scrollToTop() : void Scrolls the grid to the top Scrolls the grid to the top Parameters: None. Returns: void | TreeGrid

## Public Events

This class has no public events.